@@ -218,6 +218,9 @@ pub struct CommandConfigs {
     /// Settings for `kbs2 rm`.
     pub rm: RmConfig,
 
+    /// Settings for `kbs2 rename`.
+    pub rename: RenameConfig,
+
     /// External command settings.
     pub ext: HashMap<String, HashMap<String, toml::Value>>,
 }
@@ -293,6 +296,15 @@ pub struct RmConfig {
     pub post_hook: Option<String>,
 }
 
+/// Configuration settings for `kbs2 rename`.
+#[derive(Clone, Debug, Default, Deserialize, Serialize)]
+#[serde(default)]
+pub struct RenameConfig {
+    #[serde(deserialize_with = "deserialize_optional_with_tilde")]
+    #[serde(rename = "post-hook")]
+    pub post_hook: Option<String>,
+}
+
 /// A "view" for an active configuration, composed with some set of argument matches
 /// from the command line.
 pub struct RuntimeConfig<'a> {
